==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/ReferenceGrantFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantFluent<A extends ReferenceGrantFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ReferenceGrantFluent.MetadataNested<A> withNewMetadata();
  public ReferenceGrantFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ReferenceGrantFluent.MetadataNested<A> editMetadata();
  public ReferenceGrantFluent.MetadataNested<A> editOrNewMetadata();
  public ReferenceGrantFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ReferenceGrantSpec getSpec();
  public ReferenceGrantSpec buildSpec();
  public A withSpec(ReferenceGrantSpec spec);
  public Boolean hasSpec();
  public ReferenceGrantFluent.SpecNested<A> withNewSpec();
  public ReferenceGrantFluent.SpecNested<A> withNewSpecLike(ReferenceGrantSpec item);
  public ReferenceGrantFluent.SpecNested<A> editSpec();
  public ReferenceGrantFluent.SpecNested<A> editOrNewSpec();
  public ReferenceGrantFluent.SpecNested<A> editOrNewSpecLike(ReferenceGrantSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ReferenceGrantFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ReferenceGrantSpecFluent<ReferenceGrantFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1alpha2/ReferenceGrantFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1alpha2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantSpec;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantSpecFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantFluent<A extends ReferenceGrantFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ReferenceGrantFluent.MetadataNested<A> withNewMetadata();
  public ReferenceGrantFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ReferenceGrantFluent.MetadataNested<A> editMetadata();
  public ReferenceGrantFluent.MetadataNested<A> editOrNewMetadata();
  public ReferenceGrantFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ReferenceGrantSpec getSpec();
  public ReferenceGrantSpec buildSpec();
  public A withSpec(ReferenceGrantSpec spec);
  public Boolean hasSpec();
  public ReferenceGrantFluent.SpecNested<A> withNewSpec();
  public ReferenceGrantFluent.SpecNested<A> withNewSpecLike(ReferenceGrantSpec item);
  public ReferenceGrantFluent.SpecNested<A> editSpec();
  public ReferenceGrantFluent.SpecNested<A> editOrNewSpec();
  public ReferenceGrantFluent.SpecNested<A> editOrNewSpecLike(ReferenceGrantSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ReferenceGrantFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ReferenceGrantSpecFluent<ReferenceGrantFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
